@@ -1,4 +1,4 @@
-/*  Copyright (C) 2013 Ben Asselstine
+/*  Copyright (C) 2013, 2014 Ben Asselstine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -21,13 +21,14 @@
 #include <config.h>
 #include <argp.h>
 #include "licensing.h"
+#include "fsf-addresses.h"
 
 struct lu_agpl_options_t
 {
   struct lu_state_t *state;
-  int html;
   int full;
   int future_versions;
+  int fsf_address;
 };
 
 int lu_agpl_parse_argp (struct lu_state_t *, int argc, char **argv);
