@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -28,6 +28,7 @@
 #include "prepend.h"
 #include "preview.h"
 #include "styles.h"
+#include "boilerplate.h"
 
 static struct argp_option argp_options[] = 
 {
@@ -36,6 +37,9 @@ static struct argp_option argp_options[] =
     {"quiet", 'q', NULL, 0, N_("don't show diagnostic messages")},
     {"after", 'a', NULL, 0,
       N_("prepend after existing boilerplate if any")},
+    {"replace", 'r', NULL, 0, N_("remove any existing boilerplate if any")},
+    {"force", 'f', NULL, 0, N_("used with -r to force removal copyright notices")},
+    {"dry-run", 'd', NULL, 0, N_("do not actually modify any files")},
     {0}
 };
 
@@ -47,6 +51,15 @@ parse_opt (int key, char *arg, struct argp_state *state)
     opt = (struct lu_apply_options_t*) state->input;
   switch (key)
     {
+    case 'd':
+      opt->dry_run = 1;
+      break;
+    case 'f':
+      opt->force = 1;
+      break;
+    case 'r':
+      opt->replace = 1;
+      break;
     case 'a':
       opt->after = 1;
       break;
@@ -66,6 +79,9 @@ parse_opt (int key, char *arg, struct argp_state *state)
       opt->quiet = 0;
       opt->style = NULL;
       opt->after = 0;
+      opt->replace = 0;
+      opt->force = 0;
+      opt->dry_run = 0;
       state->child_inputs[0] = &opt->style;
       break;
     case ARGP_KEY_FINI:
@@ -79,6 +95,12 @@ parse_opt (int key, char *arg, struct argp_state *state)
           argp_failure (state, 0, 0, N_("did you mean to use --after?"));
           argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
         }
+      if (opt->force && !opt->replace)
+        {
+          argp_failure (state, 0, 0,
+                        N_("--force can only be used with --remove"));
+          argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
+        }
       break;
     default:
       return ARGP_ERR_UNKNOWN;
@@ -154,17 +176,65 @@ lu_apply (struct lu_state_t *state, struct lu_apply_options_t *options)
             }
         }
       
-      struct lu_prepend_options_t prepend_options;
-      prepend_options.backup = options->backup;
-      prepend_options.after = options->after;
-      prepend_options.style = options->style;
-      prepend_options.source = boilerplate;
-      prepend_options.dest = f;
-      err = lu_prepend (state, &prepend_options);
-      if (!err)
+      if (options->replace)
         {
-          if (options->quiet == 0)
-            error (0, 0, N_("%s -> Boilerplate applied."), f);
+          int removed = 0;
+          struct lu_boilerplate_options_t boilerplate_options;
+          boilerplate_options.remove = 1;
+          boilerplate_options.force = options->force;
+          memset (boilerplate_options.blocks, 0,
+                  sizeof (boilerplate_options.blocks));
+          boilerplate_options.blockspec = NULL;
+          boilerplate_options.no_backups = !options->backup;
+          boilerplate_options.quiet = 1;
+          boilerplate_options.style = options->style;
+          boilerplate_options.input_files = NULL;
+          boilerplate_options.input_files_len = 0;
+          boilerplate_options.dry_run = options->dry_run;
+          argz_add (&boilerplate_options.input_files,
+                    &boilerplate_options.input_files_len,
+                    f);
+          err = lu_boilerplate (state, &boilerplate_options, &removed);
+
+          if (!err)
+            {
+              struct lu_prepend_options_t prepend_options;
+              prepend_options.backup = 0;
+              prepend_options.dry_run = options->dry_run;
+              prepend_options.after = options->after;
+              prepend_options.style = options->style;
+              prepend_options.source = boilerplate;
+              prepend_options.dest = f;
+              prepend_options.quiet = 1;
+              err = lu_prepend (state, &prepend_options);
+              if (!err)
+                {
+                  if (options->quiet == 0)
+                    {
+                      if (removed)
+                        error (0, 0, N_("%s -> Boilerplate replaced."), f);
+                      else
+                        error (0, 0, N_("%s -> Boilerplate applied."), f);
+                    }
+                }
+            }
+        }
+      else
+        {
+          struct lu_prepend_options_t prepend_options;
+          prepend_options.backup = 1;
+          prepend_options.dry_run = options->dry_run;
+          prepend_options.after = options->after;
+          prepend_options.style = options->style;
+          prepend_options.source = boilerplate;
+          prepend_options.dest = f;
+          prepend_options.quiet = 1;
+          err = lu_prepend (state, &prepend_options);
+          if (!err)
+            {
+              if (options->quiet == 0)
+                error (0, 0, N_("%s -> Boilerplate applied."), f);
+            }
         }
       if (err)
         break;
@@ -177,7 +247,7 @@ struct lu_command_t apply =
 {
   .name         = N_("apply"),
   .doc          = APPLY_DOC,
-  .flags        = SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SHOW_IN_HELP | SAVE_IN_HISTORY | IS_MOST_FREQUENTLY_USED,
   .argp         = &argp,
   .parser       = lu_apply_parse_argp
 };
