@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -31,6 +31,9 @@ struct lu_apply_options_t
   int quiet;
   struct lu_comment_style_t *style;
   int after;
+  int replace;
+  int force;
+  int dry_run;
 };
 
 int lu_apply_parse_argp (struct lu_state_t *, int argc, char **argv);
