@@ -1,4 +1,4 @@
-/*  Copyright (C) 2013 Ben Asselstine
+/*  Copyright (C) 2013, 2014, 2017 Ben Asselstine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -24,6 +24,7 @@
 #include "licensing_priv.h"
 #include "boilerplate.h"
 #include "gettext-more.h"
+#include "read-file.h"
 #include "xvasprintf.h"
 #include "trim.h"
 #include "error.h"
@@ -35,17 +36,21 @@ enum
   OPT_UNCOMMENT = -211,
   OPT_WHITESPACE,
   OPT_COUNT,
+  OPT_FULL,
 };
 
 static struct argp_option argp_options[] = 
 {
+    {"full", OPT_FULL, NULL, 0, N_("instead of topmost comments, show them all")},
     {"remove", 'r', NULL, 0, 
       N_("remove boilerplate from FILE instead of showing")},
-    {"force", 'f', NULL, 0, N_("force the removal copyright notices")},
+    {"force", 'f', NULL, 0, N_("used with -r to force removal copyright notices")},
     {"blocks", 'b', "LIST", 0, 
       N_("select these comment blocks to show or remove")},
     {"no-backup", 'n', NULL, 0, N_("don't save .bak files when removing boilerplate")},
     {"quiet", 'q', NULL, 0, N_("don't show diagnostic messages")},
+    {"dry-run", 'd', NULL, 0, N_("do not actually modify any files")},
+    {"verbose", 'v', NULL, 0, N_("always print headers giving file names")},
     {0}
 };
 
@@ -98,6 +103,15 @@ parse_opt (int key, char *arg, struct argp_state *state)
     opt = (struct lu_boilerplate_options_t*) state->input;
   switch (key)
     {
+    case OPT_FULL:
+      opt->full = 1;
+      break;
+    case 'v':
+      opt->show_filename = 1;
+      break;
+    case 'd':
+      opt->dry_run = 1;
+      break;
     case 'q':
       opt->quiet = 1;
       break;
@@ -123,6 +137,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
       argz_add (&opt->input_files, &opt->input_files_len, arg);
       break;
     case ARGP_KEY_INIT:
+      opt->full = 0;
       opt->input_files = NULL;
       opt->input_files_len = 0;
       opt->remove = 0;
@@ -130,14 +145,34 @@ parse_opt (int key, char *arg, struct argp_state *state)
       opt->blockspec = NULL;
       opt->no_backups = 0;
       opt->quiet = 0;
+      opt->dry_run = 0;
+      opt->show_filename = 0;
       memset (opt->blocks, '\0', sizeof (opt->blocks));
       opt->style = NULL;
       state->child_inputs[0] = &opt->style;
       break;
     case ARGP_KEY_FINI:
+      if (opt->remove && opt->full)
+        {
+          argp_failure (state, 0, 0,
+                        N_("--full cannot be used with --remove"));
+          argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
+        }
+      if (opt->remove && opt->blockspec)
+        {
+          argp_failure (state, 0, 0,
+                        N_("-b cannot be used with --remove"));
+          argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
+        }
+      if (opt->dry_run && !opt->remove)
+        {
+          argp_failure (state, 0, 0,
+                        N_("--dry-run can only be used with --remove"));
+          argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
+        }
       if (opt->force && !opt->remove)
         {
-          argp_failure (state, 0, 0, 
+          argp_failure (state, 0, 0,
                         N_("--force can only be used with --remove"));
           argp_state_help (state, stderr, ARGP_HELP_STD_ERR);
         }
@@ -177,7 +212,7 @@ lu_boilerplate_parse_argp (struct lu_state_t *state, int argc, char **argv)
 
   int err = argp_parse (&argp, argc, argv, state->argp_flags, 0, &opts);
   if (!err)
-    return lu_boilerplate (state, &opts);
+    return lu_boilerplate (state, &opts, NULL);
   else
     return err;
 }
@@ -219,19 +254,16 @@ show_lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *
 {
   char *comment_blocks = NULL;
   size_t len = 0;
-  FILE *fp = fopen (file, "r");
-  if (!fp)
-    return 0;
   if (options->style == NULL)
-    auto_detect_comment_blocks (file, fp, &comment_blocks, &len, NULL);
-  else
-    options->style->get_initial_comment (fp, &comment_blocks, &len, NULL);
-  fclose (fp);
+    options->style = auto_detect_style (file);
+  if (options->style)
+    options->style->get_initial_comment (file, &comment_blocks, &len, NULL,
+                                         options->full, 0, 0, 0, 0);
   if (comment_blocks)
     {
       if (options->blockspec && 
           get_max_block (options->blocks) > argz_count (comment_blocks, len))
-        error (0, 0, N_("invalid block id %d"), 
+        error (0, 0, N_("invalid block id %ld"),
                get_max_block (options->blocks));
       else
         {
@@ -261,131 +293,108 @@ comments_contain_copyright_notice (char *argz, size_t len)
 {
   char *c = NULL;
   while ((c = argz_next (argz, len, c)))
-    if (g_regex_match_simple ("[Cc]opyright.*(19[0-9][0-9]|20[0-9][0-9])", c, 
-                              G_REGEX_CASELESS, 0))
-      return 1;
+    {
+      if (g_regex_match_simple ("[Cc]opyright.*(19[0-9][0-9]|20[0-9][0-9])", c, 
+                                G_REGEX_CASELESS, 0))
+        return 1;
+      if (g_regex_match_simple ("\\([Cc]\\)", c, G_REGEX_CASELESS, 0))
+        return 1;
+    }
   return 0;
 }
 
 static int
-remove_lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options, char *filename, int from_stdout)
+remove_lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options, char *filename, int to_stdout, int *removed)
 {
-  struct stat st;
-  char *comment_blocks = NULL;
-  size_t len = 0;
-  int err = 0;
   FILE *fp = fopen (filename, "r");
   if (!fp)
-    return err;
-  fstat (fileno (fp), &st);
-  char *hashbang = NULL;
-  if (options->style == NULL)
-    auto_detect_comment_blocks (filename, fp, &comment_blocks, &len, &hashbang);
-  else
-    options->style->get_initial_comment (fp, &comment_blocks, &len, &hashbang);
-  if (comment_blocks == NULL)
+    return 1;
+
+  if (!options->style)
+    options->style = auto_detect_style (filename);
+  if (!options->style)
     {
-      error (0, 0, N_("no boilerplate found in `%s'"), filename);
-      return err;
+      fclose (fp);
+      return 0;
     }
-  if (comments_contain_copyright_notice (comment_blocks, len))
+  char *argz = NULL;
+  size_t len = 0;
+  int sr, sc, dr, dc;
+  options->style->get_initial_comment (filename, &argz, &len, NULL, 0,
+                                       &sr, &sc, &dr, &dc);
+
+  if (comments_contain_copyright_notice (argz, len))
     {
       if (options->force == 0)
         {
           error (0, 0, N_("`%s' contains copyright notices.  "
                           "use --force to remove them."), filename);
-          free (comment_blocks);
-          return 0;
+          free (argz);
+          fclose (fp);
+          return 1;
         }
     }
-  if (options->blockspec && 
-      get_max_block (options->blocks) > argz_count (comment_blocks, len))
+
+  free (argz);
+  size_t data_len;
+  char *data = fread_file (fp, &data_len);
+  fclose (fp);
+
+  int s, e;
+  lu_get_byte_offsets (data, data_len, sr, sc, dr, dc, &s, &e);
+  memmove (&data[s], &data[e], strlen (&data[e]) + 1);
+ 
+  //to_stdout means we're not changing a file, just pumping out the result.
+  if (to_stdout)
     {
-      error (0, 0, N_("invalid block id %d"), get_max_block (options->blocks));
-      free (comment_blocks);
+      luprintf (state, "%s", data);
+      free (data);
       return 0;
     }
-  //okay now we're going to remove the comments specified in the blockspec.
-  if (options->blockspec)
-    remove_blocks_in_blocklist (&comment_blocks, &len, options->blocks, 1);
-  else
-    {
-      // remove them all ralphie boy
-      free (comment_blocks);
-      comment_blocks = NULL;
-      len = 0;
-    }
-
 
+  //okay we're changing a file, so we have to make a backup.
+  //if we're not keeping backups we delete it later.
+  struct stat st;
+  stat (filename, &st);
   char *swpfilename = xasprintf ("%s.swp", filename);
   char *bakfilename = xasprintf ("%s.bak", filename);
-  FILE *out;
-  if (from_stdout)
-    out = stdout;
-  else
-    out = fopen (swpfilename, "w");
-  if (out)
+  FILE *out = fopen (swpfilename, "w");
+  if (!out)
     {
-      if (hashbang)
+      free (data);
+      return 2;
+    }
+  fprintf (out, "%s", data);
+  fclose (out);
+  free (data);
+
+  if (chmod (swpfilename, st.st_mode))
+    error (0, errno, N_("could not chmod `%s'"), swpfilename);
+  else
+    {
+      if (options->dry_run == 0)
         {
-          fprintf (out, "%s", hashbang);
-          free (hashbang);
-        }
-      if (comment_blocks)
-        {
-          char *c = NULL;
-          while ((c = argz_next (comment_blocks, len, c)))
-            fprintf (out, "%s\n", c);
-        }
-      char *line = NULL;
-      size_t linelen = 0;
-      if (!feof (fp))
-        {
-          ssize_t read = getline (&line, &linelen, fp);
-          if (read != -1 && strspn (line, "\n\r\t\v ") != strlen (line))
-            fprintf (out, "%s", line);
-          if (read != -1)
-            while ((read = getline (&line, &linelen, fp)) != -1) 
-              fprintf (out, "%s", line);
-        }
-      free(line);
-      if (!from_stdout)
-        fclose (out);
-      err = chmod (swpfilename, st.st_mode);
-      if (err)
-        error (0, errno, N_("could not chmod `%s'"), swpfilename);
-      else
-        {
-          err = rename (filename, bakfilename);
-          if (err)
-            error (0, errno, N_("could not move %s -> %s"), filename, 
+          if (rename (filename, bakfilename))
+            error (0, errno, N_("could not move %s -> %s"), filename,
                    bakfilename);
           else
             {
-              err = rename (swpfilename, filename);
-              if (err)
+              if (rename (swpfilename, filename))
                 error (0, errno, N_("could not move %s -> %s"), swpfilename,
                        filename);
             }
         }
-      if (from_stdout || options->no_backups)
-        {
-          err = remove (bakfilename);
-          if (err)
-            error (0, errno, N_("could not remove `%s'"), bakfilename);
-        }
+      if (options->quiet == 0)
+        error (0, 0, N_("%s -> Boilerplate removed."), filename);
+
+      if (options->no_backups)
+        remove (bakfilename);
     }
-  else
-    err = -1;
-  free (swpfilename);
-  free (bakfilename);
-  free (comment_blocks);
-  fclose (fp);
-  return err;
+  return 0;
 }
 
 static int
-boilerplate_from_stdin (struct lu_state_t *state, struct lu_boilerplate_options_t *options)
+boilerplate_from_stdin (struct lu_state_t *state, struct lu_boilerplate_options_t *options, int *removed)
 {
   int err = 0;
   char tmp[sizeof(PACKAGE) + 13];
@@ -406,8 +415,10 @@ boilerplate_from_stdin (struct lu_state_t *state, struct lu_boilerplate_options_
       fflush (fileptr);
       fsync (fileno (fileptr));
       fclose (fileptr);
+      if (options->show_filename)
+        luprintf (state, "==> standard input <==\n");
       if (options->remove)
-        err = remove_lu_boilerplate (state, options, tmp, 1);
+        err = remove_lu_boilerplate (state, options, tmp, 1, removed);
       else
         err = show_lu_boilerplate (state, options, tmp);
       remove (tmp);
@@ -418,14 +429,14 @@ boilerplate_from_stdin (struct lu_state_t *state, struct lu_boilerplate_options_
 }
 
 static int
-show_lu_boilerplate_for_files(struct lu_state_t *state, struct lu_boilerplate_options_t *options)
+show_lu_boilerplate_for_files(struct lu_state_t *state, struct lu_boilerplate_options_t *options, int *removed)
 {
   int err = 0;
   char *f = NULL;
   while ((f = argz_next (options->input_files, options->input_files_len, f)))
     {
       if (strcmp (f, "-") == 0)
-        err = boilerplate_from_stdin (state, options);
+        err = boilerplate_from_stdin (state, options, removed);
       else
         {
           if (is_a_file (f) == 0)
@@ -448,10 +459,14 @@ show_lu_boilerplate_for_files(struct lu_state_t *state, struct lu_boilerplate_op
 
                   continue;
                 }
-              err = remove_lu_boilerplate (state, options, f, 0);
+              err = remove_lu_boilerplate (state, options, f, 0, removed);
             }
           else
-            err = show_lu_boilerplate (state, options, f);
+            {
+              if (options->show_filename)
+                luprintf (state, "==> %s <==\n", f);
+              err = show_lu_boilerplate (state, options, f);
+            }
         }
       if (err)
         break;
@@ -460,13 +475,13 @@ show_lu_boilerplate_for_files(struct lu_state_t *state, struct lu_boilerplate_op
 }
 
 int 
-lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options)
+lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options, int *removed)
 {
   int err = 0;
   if (options->input_files == NULL)
-    err = boilerplate_from_stdin (state, options);
+    err = boilerplate_from_stdin (state, options, removed);
   else
-    err = show_lu_boilerplate_for_files (state, options);
+    err = show_lu_boilerplate_for_files (state, options, removed);
   free (options->input_files);
   return err;
 }
@@ -475,7 +490,7 @@ struct lu_command_t boilerplate =
 {
   .name         = N_("boilerplate"),
   .doc          = BOILERPLATE_DOC,
-  .flags        = SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SHOW_IN_HELP | SAVE_IN_HISTORY | IS_MOST_FREQUENTLY_USED,
   .argp         = &argp,
   .parser       = lu_boilerplate_parse_argp
 };
