@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -36,9 +36,12 @@ struct lu_boilerplate_options_t
   struct lu_comment_style_t *style;
   char *input_files;
   size_t input_files_len;
+  int dry_run;
+  int show_filename;
+  int full;
 };
 
 int lu_boilerplate_parse_argp (struct lu_state_t *, int argc, char **argv);
-int lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options);
+int lu_boilerplate (struct lu_state_t *state, struct lu_boilerplate_options_t *options, int *removed);
 extern struct lu_command_t boilerplate;
 #endif
