@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -156,15 +156,13 @@ count_boilerplate_blocks (struct lu_state_t *state, struct lu_cbb_options_t *opt
         error (0, errno, N_("could not open `%s' for reading"), file);
       return 0;
     }
-  FILE *fp = fopen (file, "r");
-  if (!fp)
-    return 0;
   if (options->style == NULL)
-    auto_detect_comment_blocks (file, fp, &comment_blocks, &len, NULL);
-  else
-    options->style->get_initial_comment (fp, &comment_blocks, &len, NULL);
-  fclose (fp);
+    options->style = auto_detect_style (file);
+  if (options->style)
+    options->style->get_initial_comment (file, &comment_blocks, &len, NULL, 0,
+                                         0, 0, 0, 0);
   show_results (state, options, comment_blocks, len, showfile ? file: NULL);
+  free (comment_blocks);
   return 0;
 }
 
@@ -225,7 +223,7 @@ struct lu_command_t cbb =
 {
   .name         = N_("cbb"),
   .doc          = CBB_DOC,
-  .flags        = DO_NOT_SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SAVE_IN_HISTORY | SHOW_IN_HELP,
   .argp         = &argp,
   .parser       = lu_cbb_parse_argp
 };
