@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -25,9 +25,10 @@ struct lu_comment_style_t
 {
   const char *name;
   const struct argp *argp;
-  int (*get_initial_comment) (FILE *fp, char **argz, size_t *len, char **hash);
+  int (*get_initial_comment) (char *file, char **argz, size_t *len, char **hash, int full, int *sr, int *sc, int *dr, int *dc);
   char* (*comment) (char *text);
   void (*uncomment) (char **argz, size_t *argz_len, int trim);
+  int multiline;
   char *support_file_exts;
   char *avoid_file_exts;
 };
