@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied copyright of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -197,7 +197,7 @@ struct lu_command_t comment =
 {
   .name         = N_("comment"),
   .doc          = COMMENT_DOC,
-  .flags        = DO_NOT_SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SAVE_IN_HISTORY | SHOW_IN_HELP,
   .argp         = &argp,
   .parser       = lu_comment_parse_argp
 };
