@@ -174,9 +174,13 @@ squeeze (char *s)
 {
   int i = 0;
   char *letter;
-  char *result = strdup (s);
-  result[0] = '\0';
-  int separated = 0;
+  size_t len = strlen (s);
+  if (len < 2)
+    len = 2;
+  char *result = malloc (len + 1);
+  result[0] = ' ';
+  result[1] = '\0';
+  int separated = 1;
   for (letter = &s[0]; *letter != '\0'; letter++)
     {
       int keyword_separator = 0;
