@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -67,9 +67,9 @@ uncomment (char **argz, size_t *len, int trim)
 }
 
 static int
-get_comment (FILE *fp, char **argz, size_t *len, char **hashbang)
+get_comment (char *file, char **argz, size_t *len, char **hashbang, int full, int *sr, int *sc, int *dr, int *dc)
 {
-  return get_comment_blocks (fp, argz, len, hashbang, "(^\\#\\ .*[\\r\\n])*");
+  return get_comments (file, "shell", argz, len, full, NULL, sr, sc, dr, dc);
 }
 
 struct lu_comment_style_t gettext_style=
@@ -79,6 +79,7 @@ struct lu_comment_style_t gettext_style=
   .get_initial_comment = get_comment,
   .comment             = comment,
   .uncomment           = uncomment,
+  .multiline           = 0,
   .support_file_exts   = ".pot .po",
   .avoid_file_exts     = NULL, // avoid no file extensions
 };
