@@ -1,4 +1,4 @@
-/*  Copyright (C) 2013 Ben Asselstine
+/*  Copyright (C) 2013, 2014 Ben Asselstine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -92,12 +92,17 @@ lu_help (struct lu_state_t *state, struct lu_help_options_t *options)
     } 
   else
     {
-      fprintf (state->out, _("List of Commands that show Licenses and License Notices:\n"));
-      char *lines = lu_list_of_commands_for_help(3);
+      fprintf (state->out, _("Frequently Used Commands:\n"));
+      char *lines = lu_list_of_commands_for_help (4);
       fprintf (state->out, "%s\n\n", lines);
       free (lines);
-      lines = lu_list_of_commands_for_help(2);
-      fprintf (state->out, _("List of Commands:\n"));
+
+      lines = lu_list_of_commands_for_help (2);
+      fprintf (state->out, _("Full List of Commands:\n"));
+      fprintf (state->out, "%s\n\n", lines);
+      free (lines);
+      fprintf (state->out, _("List of Commands that show Licenses and License Notices:\n"));
+      lines = lu_list_of_commands_for_help (3);
       fprintf (state->out, "%s\n", lines);
       free (lines);
       fprintf (state->out, "\n%s\n", 
@@ -110,7 +115,7 @@ struct lu_command_t help =
 {
   .name         = N_("help"),
   .doc          = HELP_DOC,
-  .flags        = DO_NOT_SHOW_IN_HELP | DO_NOT_SAVE_IN_HISTORY,
+  .flags        = DO_NOT_SAVE_IN_HISTORY | SHOW_IN_HELP,
   .argp         = &argp,
   .parser       = lu_help_parse_argp
 };
