@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -22,6 +22,7 @@
 #include "gettext-more.h"
 #include "m4-style.h"
 #include "util.h"
+#include "xvasprintf.h"
 
 enum {
   OPT_M4 = -113,
@@ -62,16 +63,15 @@ comment (char *text)
 static void
 uncomment (char **argz, size_t *len, int trim)
 {
+  uncomment_comments (argz, len, "#", NULL, trim, 0, 0);
   uncomment_comments (argz, len, "dnl", NULL, trim, 1, 0);
   return;
 }
 
 static int
-get_comment (FILE *fp, char **argz, size_t *len, char **hashbang)
+get_comment (char *file, char **argz, size_t *len, char **hashbang, int full, int *sr, int *sc, int *dr, int *dc)
 {
-  return get_comment_blocks 
-    (fp, argz, len, hashbang, 
-     "((^[Dd][Nn][Ll][ \t]|^\\#).*[\\r\\n]|^[Dd][Nn][Ll][\r\n])*");
+  return get_comments (file, "m4", argz, len, full, NULL, sr, sc, dr, dc);
 }
 
 struct lu_comment_style_t m4_style=
@@ -81,6 +81,7 @@ struct lu_comment_style_t m4_style=
   .get_initial_comment = get_comment,
   .comment             = comment,
   .uncomment           = uncomment,
+  .multiline           = 0,
   .support_file_exts   = ".m4 .ac",
   .avoid_file_exts     = NULL,
 };
