@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -27,6 +27,7 @@
 #include "gettext-more.h"
 #include "opts.h"
 #include "licensing_priv.h"
+#include "styles.h"
 
 #define FULL_VERSION PROGRAM " " PACKAGE_VERSION
 
@@ -38,6 +39,9 @@ static struct argp_option options[] =
 {
     { "quiet", OPT_QUIET, NULL, 0, N_("don't show the welcome message") },
     { "generate-bashrc", OPT_BASH, NULL, OPTION_HIDDEN, N_("generate a bashrc file and exit") },
+    { "list-styles", OPT_LIST_STYLES, NULL, OPTION_HIDDEN, N_("show all supported styles")},
+    { "list-licenses", OPT_LIST_LICENSES, NULL, OPTION_HIDDEN, N_("show some licenses")},
+    { "list-all-licenses", OPT_LIST_ALL_LICENSES, NULL, OPTION_HIDDEN, N_("show all supported licenses")},
     { 0 }
 };
 
@@ -57,6 +61,53 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
   switch (key) 
     {
+    case OPT_LIST_STYLES:
+      list_all_comment_style_options();
+      exit (0);
+      break;
+    case OPT_LIST_ALL_LICENSES:
+        {
+          struct lu_license_t *licenses = lu_list_of_licenses (NULL);
+          int i = 0;
+          int first = 1;
+          while (licenses[i].keyword)
+            {
+              if (first)
+                first = 0;
+              else
+                printf (" ");
+              printf ("%s", licenses[i].keyword);
+              i++;
+            }
+          printf("\n");
+          free (licenses);
+        }
+      exit (0);
+      break;
+    case OPT_LIST_LICENSES:
+        {
+          struct lu_license_t *licenses = lu_list_of_licenses (NULL);
+          int i = 0;
+          int first = 1;
+          while (licenses[i].keyword)
+            {
+              if (strchr (licenses[i].keyword, ','))
+                {
+                  i++;
+                  continue;
+                }
+              if (first)
+                first = 0;
+              else
+                printf (" ");
+              printf ("%s", licenses[i].keyword);
+              i++;
+            }
+          printf("\n");
+          free (licenses);
+        }
+      exit (0);
+      break;
     case OPT_QUIET:
       arguments->lu.quiet = 1;
       break;
@@ -97,7 +148,7 @@ help_filter (int key, const char *text, void *input)
       argz_add (&argz, &len, text);
       argz_add (&argz, &len, "");
       argz_add (&argz, &len, "The most commonly used commands are:");
-      char *commands = lu_list_of_commands_for_help(0);
+      char *commands = lu_list_of_commands_for_help(4);
       argz_add (&argz, &len, commands);
       free (commands);
       argz_add (&argz, &len, "");
