@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -36,6 +36,8 @@ static struct argp_option argp_options[] =
       N_("don't retain original source file in a .bak file")},
     {"after", 'a', NULL, 0,
       N_("prepend after existing boilerplate if any")},
+    {"dry-run", 'd', NULL, 0, N_("do not actually modify any files")},
+    {"quiet", 'q', NULL, 0, N_("don't show diagnostic messages")},
     {0}
 };
 
@@ -47,6 +49,12 @@ parse_opt (int key, char *arg, struct argp_state *state)
     opt = (struct lu_prepend_options_t*) state->input;
   switch (key)
     {
+    case 'q':
+      opt->quiet = 1;
+      break;
+    case 'd':
+      opt->dry_run = 1;
+      break;
     case 'a':
       opt->after = 1;
       break;
@@ -68,6 +76,8 @@ parse_opt (int key, char *arg, struct argp_state *state)
       opt->backup = 1;
       opt->style = NULL;
       opt->after = 0;
+      opt->dry_run = 0;
+      opt->quiet = 0;
       state->child_inputs[0] = &opt->style;
       break;
     case ARGP_KEY_FINI:
@@ -117,7 +127,6 @@ lu_prepend (struct lu_state_t *state, struct lu_prepend_options_t *options)
   struct stat st;
   int err = 0;
   FILE *src = NULL;
-  FILE *dst = NULL;
   memset (&st, 0, sizeof (st));
   if (strcmp (options->source, "-") == 0 || options->source == NULL)
     src = stdin;
@@ -140,24 +149,7 @@ lu_prepend (struct lu_state_t *state, struct lu_prepend_options_t *options)
   if (src != stdin && src != NULL)
     fclose (src);
   
-  char *comments = NULL;
-  size_t dest_len = 0;
-  char *dest = NULL;
-  char *hashbang = NULL;
-  if (is_a_file (options->dest) != 0)
-    {
-      dst = fopen (options->dest, "r");
-      if (dst)
-        {
-          get_hashbang_or_rewind (dst, &hashbang);
-          if (options->after)
-            comments = get_comments_and_whitespace (dst, options->dest, 
-                                                    options->style);
-          //the rest
-          dest = fread_file (dst, &dest_len);
-        }
-    }
-  else
+  if (is_a_file (options->dest) == 0)
     {
       if (errno == EISDIR)
         error (0, errno, "%s", options->dest);
@@ -166,11 +158,60 @@ lu_prepend (struct lu_state_t *state, struct lu_prepend_options_t *options)
       return 1;
     }
 
-  if (dst)
+
+  if (options->style == NULL)
+    options->style = auto_detect_style (options->dest);
+
+  char *comments = NULL;
+  size_t comments_len = 0;
+  size_t dest_len = 0;
+  char *dest = NULL;
+  char *hashbang = NULL;
+  
+  int sr, sc, dr, dc;
+  if (options->style)
+    options->style->get_initial_comment (options->dest,
+                                         &comments, &comments_len,
+                                         &hashbang, 0, &sr, &sc, &dr, &dc);
+
+  FILE *dst = fopen (options->dest, "r");
+  if (comments_len != 0)
     {
-      fstat (fileno (dst), &st);
-      fclose (dst);
+      //the rest
+      dest = fread_file (dst, &dest_len);
+      int s = 0, e = 0;
+      lu_get_byte_offsets (dest, dest_len, sr, sc, dr, dc, &s, &e);
+      memmove (&dest[s], &dest[e], strlen (&dest[e]) + 1);
+      argz_stringify (comments, comments_len, '\n');
     }
+  else
+    {
+      dest = fread_file (dst, &dest_len);
+      if (hashbang)
+        {
+          char *start = 0;
+          start += strlen (hashbang);
+          memmove (dest, start, strlen (start) + 1);
+        }
+      else
+        {
+          if (strncmp (dest, "#!", 2) == 0)
+            {
+              char *nl = strchr (dest, '\n');
+              if (nl)
+                {
+                  nl++;
+                  char old = *nl;
+                  *nl = '\0';
+                  hashbang = strdup (dest);
+                  *nl = old;
+                  memmove (dest, nl, strlen (nl) + 1);
+                }
+            }
+        }
+    }
+  fclose (dst);
+  stat (options->dest, &st);
 
   //okay we have source, and we have dest, and we have hashbang.
   //we might also have comments
@@ -186,6 +227,8 @@ lu_prepend (struct lu_state_t *state, struct lu_prepend_options_t *options)
       if (options->after && comments)
         fprintf (out, "%s", comments);
       fprintf (out, "%s", source);
+      if (!options->after && comments)
+        fprintf (out, "%s", comments);
       fprintf (out, "%s", dest);
       fflush (out);
       fsync (fileno (out));
@@ -197,33 +240,50 @@ lu_prepend (struct lu_state_t *state, struct lu_prepend_options_t *options)
 
       if (!err)
         {
-          if (options->backup)
+          if (options->dry_run == 0)
             {
-              char *backup = xasprintf ("%s.bak", options->dest);
-              err = rename (options->dest, backup);
-              if (err)
-                error (0, errno, N_("couldn't move %s -> %s"), options->dest, 
-                       backup);
-              free (backup);
-            }
-          else
-            {
-              err = remove (options->dest);
-              if (err)
-                error (0, errno, N_("couldn't remove `%s'"), options->dest);
+              if (options->backup)
+                {
+                  char *backup = xasprintf ("%s.bak", options->dest);
+                  err = rename (options->dest, backup);
+                  if (err)
+                    error (0, errno, N_("couldn't move %s -> %s"),
+                           options->dest, backup);
+                  free (backup);
+                }
+              else
+                {
+                  err = remove (options->dest);
+                  if (err)
+                    error (0, errno, N_("couldn't remove `%s'"), options->dest);
+                }
             }
         }
 
       if (!err)
         {
-          err = qcopy_file_preserving (tmp, options->dest);
-          if (err)
-            error (0, errno, N_("couldn't copy %s -> %s"), tmp, options->dest);
+          if (options->dry_run == 0)
+            {
+              err = qcopy_file_preserving (tmp, options->dest);
+              if (err)
+                error (0, errno, N_("couldn't copy %s -> %s"), tmp,
+                       options->dest);
+            }
+          else
+            remove (tmp);
+          if (options->quiet == 0)
+            {
+              if (options->after)
+                error (0, 0, N_("%s -> File appended."), options->dest);
+              else
+                error (0, 0, N_("%s -> File prepended."), options->dest);
+            }
         }
     }
   free (source);
   free (dest);
   free (hashbang);
+  free (comments);
   return err;
 }
 
