@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -30,6 +30,8 @@ struct lu_prepend_options_t
   int backup;
   struct lu_comment_style_t *style;
   int after;
+  int dry_run;
+  int quiet;
 };
 
 int lu_prepend_parse_argp (struct lu_state_t *, int argc, char **argv);
