@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -23,6 +23,7 @@
 #include "project.h"
 #include "gettext-more.h"
 #include "read-file.h"
+#include "error.h"
 
 enum {
   OPT_BELONGS = -120,
@@ -54,7 +55,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
     case 'r':
       remove (get_config_file ("project-line"));
       if (opt->quiet == 0)
-        fprintf (stderr, "Removed.\n");
+        error (0, 0, "Removed.");
       exit (0);
       break;
     case ARGP_KEY_ARG:
@@ -112,7 +113,7 @@ lu_project (struct lu_state_t *state, struct lu_project_options_t *options)
         }
       free (options->text);
       if (options->quiet == 0)
-        fprintf (stderr, "Added.\n");
+        error (0, 0, "Added.");
     }
   else
     {
@@ -141,7 +142,7 @@ struct lu_command_t project =
 {
   .name         = N_("project"),
   .doc          = PROJECT_DOC,
-  .flags        = DO_NOT_SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SAVE_IN_HISTORY | SHOW_IN_HELP,
   .argp         = &argp,
   .parser       = lu_project_parse_argp
 };
