@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -63,10 +63,9 @@ uncomment (char **argz, size_t *len, int trim)
 }
 
 static int
-get_comment (FILE *fp, char **argz, size_t *len, char **hashbang)
+get_comment (char *file, char **argz, size_t *len, char **hashbang, int full, int *sr, int *sc, int *dr, int *dc)
 {
-  get_hashbang_or_rewind (fp, hashbang);
-  return get_comment_blocks (fp, argz, len, hashbang, "(^\\#.*[\\r\\n])*");
+  return get_comments (file, "shell", argz, len, full, hashbang, sr, sc, dr, dc);
 }
 
 struct lu_comment_style_t shell_style=
@@ -76,6 +75,7 @@ struct lu_comment_style_t shell_style=
   .get_initial_comment = get_comment,
   .comment             = comment,
   .uncomment           = uncomment,
+  .multiline           = 0,
   .support_file_exts   = NULL, // support all file extensions
   .avoid_file_exts     = ".c .h .cpp .hpp .hh .cc .m4 .ac .po .pot",
 };
