@@ -1,4 +1,4 @@
-/*  Copyright (C) 2013 Ben Asselstine
+/*  Copyright (C) 2013, 2017 Ben Asselstine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -43,6 +43,9 @@
 #ifdef SUPPORT_HASKELL_STYLE
 #include "haskell-style.h"
 #endif
+#ifdef SUPPORT_JAVASCRIPT_STYLE
+#include "javascript-style.h"
+#endif
 #ifdef SUPPORT_M4_STYLE
 #include "m4-style.h"
 #endif
@@ -58,6 +61,9 @@
 #ifdef SUPPORT_TEXINFO_STYLE
 #include "texinfo-style.h"
 #endif
+#ifdef SUPPORT_LATEX_STYLE
+#include "latex-style.h"
+#endif
 
 struct lu_comment_style_t* lu_styles[]=
 {
@@ -70,6 +76,9 @@ struct lu_comment_style_t* lu_styles[]=
 #ifdef SUPPORT_CPLUSPLUS_STYLE
     &cplusplus_style,
 #endif
+#ifdef SUPPORT_JAVASCRIPT_STYLE
+    &javascript_style,
+#endif
 #ifdef SUPPORT_SHELL_STYLE
     &shell_style,
 #endif
@@ -79,6 +88,9 @@ struct lu_comment_style_t* lu_styles[]=
 #ifdef SUPPORT_TEXINFO_STYLE
     &texinfo_style,
 #endif
+#ifdef SUPPORT_LATEX_STYLE
+    &latex_style,
+#endif
 #ifdef SUPPORT_M4_STYLE
     &m4_style,
 #endif
@@ -109,6 +121,9 @@ parsers[] =
 #ifdef SUPPORT_CPLUSPLUS_STYLE
     {&cplusplus_style_argp},
 #endif
+#ifdef SUPPORT_JAVASCRIPT_STYLE
+    {&javascript_style_argp},
+#endif
 #ifdef SUPPORT_FORTRAN_STYLE
     {&fortran_style_argp},
 #endif
@@ -135,6 +150,9 @@ parsers[] =
 #endif
 #ifdef SUPPORT_TEXINFO_STYLE
     {&texinfo_style_argp},
+#endif
+#ifdef SUPPORT_LATEX_STYLE
+    {&latex_style_argp},
 #endif
     { 0 },
 
@@ -191,16 +209,11 @@ match_file_extension (char *extensions, char *filename)
 }
 
 struct lu_comment_style_t *
-auto_detect_comment_blocks (char *filename, FILE *fp, char **argz, size_t *len, char **hashbang)
+auto_detect_style (char *filename)
 {
-  char *hashbang_throwaway = NULL;
-  char **h = hashbang;
-  if (!h)
-    h = &hashbang_throwaway;
   struct lu_comment_style_t **style = &lu_styles[0];
   while (*style)
     {
-      rewind (fp);
       int match = 0;
       if ((*style)->support_file_exts)
         {
@@ -214,13 +227,18 @@ auto_detect_comment_blocks (char *filename, FILE *fp, char **argz, size_t *len,
           match_file_extension ((*style)->avoid_file_exts, filename))
         match = 0;
 
-      if (match && (*style)->get_initial_comment (fp, argz, len, h))
+      //fprintf (stderr, "checking %s\n", (*style)->name);
+      char *argz = NULL;
+      size_t len = 0;
+      int m = match &&
+        (*style)->get_initial_comment (filename, &argz, &len, 0, 0, 0, 0, 0, 0);
+      if (argz)
+        free (argz);
+      if (m)
         break;
 
       style++;
     }
-  if (hashbang_throwaway)
-    free (hashbang_throwaway);
   return (*style);
 }
 
@@ -249,12 +267,27 @@ lu_is_a_comment_style (char *arg)
   return lu_lookup_comment_style (arg) == NULL ? 0 : 1;
 }
 
-      
-static void
+void
+list_all_comment_style_options()
+{
+  struct lu_comment_style_t **style = &lu_styles[0];
+  int first = 1;
+  while (*style)
+    {
+      if (first)
+        first = 0;
+      else
+        printf(" ");
+      printf("%s", (*style)->name);
+      style++;
+    }
+  printf("\n");
+}
+
+void
 show_all_comment_style_options()
 {
   struct lu_comment_style_t **style = &lu_styles[0];
-  printf (" Commenting Style Options:\n");
   while (*style)
     {
       const struct argp_option *options = &(*style)->argp->options[0];
@@ -307,6 +340,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   switch (key)
     {
     case OPT_VIEW_ALL:
+      printf (" Commenting Style Options:\n");
       show_all_comment_style_options();
       exit (0);
       break;
