@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -25,6 +25,8 @@ struct lu_comment_style_t * get_default_commenting_style();
 struct lu_comment_style_t * lu_lookup_comment_style (char *arg);
 int lu_is_a_comment_style (char *arg);
 char * lu_list_of_comment_styles();
-struct lu_comment_style_t * auto_detect_comment_blocks (char *filename, FILE *fp, char **argz, size_t *len, char **hashbang);
+struct lu_comment_style_t * auto_detect_style (char *filename);
 struct lu_comment_style_t * lu_get_current_commenting_style();
+void show_all_comment_style_options();
+void list_all_comment_style_options();
 #endif
