@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -23,11 +23,12 @@
 #include "top.h"
 #include "gettext-more.h"
 #include "read-file.h"
+#include "error.h"
 
 static struct argp_option argp_options[] = 
 {
     {"remove", 'r', NULL, 0, 
-      N_("remove the top line from the current working boilerplate.")},
+      N_("remove the topmost line from the current working boilerplate.")},
     {"quiet", 'q', NULL, 0, N_("don't show diagnostic messages")},
     {0}
 };
@@ -46,7 +47,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
     case 'r':
       remove (get_config_file ("top-line"));
       if (opt->quiet == 0)
-        fprintf (stderr, "Removed.\n");
+        error (0, 0, "Removed.");
       exit (0);
       break;
     case ARGP_KEY_ARG:
@@ -99,7 +100,7 @@ lu_top (struct lu_state_t *state, struct lu_top_options_t *options)
         }
       free (options->text);
       if (options->quiet == 0)
-        fprintf (stderr, "Added.\n");
+        error (0, 0, "Added.");
     }
   else
     {
@@ -126,9 +127,9 @@ lu_top (struct lu_state_t *state, struct lu_top_options_t *options)
 
 struct lu_command_t top = 
 {
-  .name         = N_("top"),
+  .name         = N_("top-line"),
   .doc          = TOP_DOC,
-  .flags        = DO_NOT_SHOW_IN_HELP | SAVE_IN_HISTORY,
+  .flags        = SAVE_IN_HISTORY | SHOW_IN_HELP,
   .argp         = &argp,
   .parser       = lu_top_parse_argp
 };
