@@ -634,8 +634,10 @@ run_comment_extractor (char *file, const char *style, char **comment_file, int f
   snprintf (tmp, sizeof tmp, "/tmp/%s.XXXXXX", PACKAGE);
   int fd = mkstemp(tmp);
   close (fd);
+  char *dir = getenv ("LU_COMMENT_EXTRACTOR_DIR");
   char *cmd =
-    xasprintf ("lu-comment-extractor %s -O %s%s -s %s --stats",
+    xasprintf ("%s%slu-comment-extractor %s -O %s%s -s %s --stats",
+               dir ? dir : "", dir ? "/": "",
                file, tmp, full ? " -f" : "", style);
   int ret = system (cmd);
   *comment_file = strdup (tmp); 
