@@ -1,4 +1,4 @@
-/*  Copyright (C) 2013 Ben Asselstine
+/*  Copyright (C) 2013, 2014, 2017 Ben Asselstine
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU Library General Public License for more details.
+  GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
@@ -31,5 +31,20 @@ void uncomment_comments (char **argz, size_t *len, char *delimiters, char *synon
 char * create_line_comment (char *text, char *delimiter);
 void get_hashbang_or_rewind (FILE *fp, char **hashbang);
 int get_comment_blocks (FILE *fp, char **argz, size_t *len, char **hashbang, char *regex);
-char * get_comments_and_whitespace (FILE *fp, char *file, struct lu_comment_style_t *style);
+char * get_lines (char *text, const char *match, int lines);
+int text_replace (char *text, char *search, char *replace);
+void replace_fsf_address (char **chunk, int fsf_address, char *license, int num_spaces);
+char * lu_load_selected_comment_style ();
+char * lu_load_selected_licenses ();
+int lu_format_and_dump_file (char *file, char *fmt, FILE *out);
+int lu_dump_file (char *file, FILE *out);
+typedef struct
+{
+  int starting_line;
+  int ending_line;
+} lu_block_t;
+
+int lu_count_blocks (char *filename, lu_block_t **blocks, int *num_blocks);
+int get_comments (char *file, const char *style, char **argz, size_t *len, int full, char **hashbang, int *, int *, int *, int *);
+void lu_get_byte_offsets (char *dest, size_t dest_len, int sr, int sc, int dr, int dc, int *s, int *e);
 #endif
